-- Let's go over an example for how to use the thing.
freeslot("sfx_talks", "sfx_talk0")
sfxinfo[sfx_talks].caption = "/"
sfxinfo[sfx_talk0].caption = "/"

local TB = CFTextBoxes -- shortcut

-- First, you must define a table to contain your textboxes. This is what we'll call a "textbox tree".
-- Various branches down the textbox tree can be taken with choices. Let's create an example tree:
local boxtree1 = {
    [1] = { -- The first textbox in the branch. The textbox numbering always starts at 1, and the textbox will always initialize to 1.
        name = "Sonic", -- The name of the speaker.
        portrait = {"sonic", SPR2_STND, A, 8}, -- The "portrait". Basically, this shows who is speaking just above the textbox. Skin, spr2, frame, angle.
        color = SKINCOLOR_BLUE, -- The color to use for the portrait.
        text = "How's it going?", -- The text to print into the box. Puts the "text" in "textbox".
        sound = sfx_talks, -- The sound to play for every letter printed.
        next = 2 -- The ID of the next textbox.
    },
    
    [2] = { -- This is going to be our choice prompt.
        choices = {
            {text = "So far so good", box = 3, pos = "left"}, -- The option itself, then the box ID it takes you to, then the relative position.
            {text = "...", box = 5, pos = "right"} -- Try to position these so that scrolling with LTR makes sense.
        }
    },
    
    [3] = { -- "So far so good"
        name = "Sonic",
        portrait = {"sonic", SPR2_TBXA, A, 1},
        color = SKINCOLOR_BLUE,
        text = "I'm |wav|esc\x82glad to hear that|rst|esc\x80!", -- You can use escape sequences and "bar commands", as I call them. More in the overview.
        sound = sfx_talks,
        next = 4
    },
    [4] = {
        name = "Sonic",
        portrait = {"sonic", SPR2_STND, A, 8},
        color = SKINCOLOR_BLUE,
        text = "Tell me if anything happens, alright, buddy?",
        sound = sfx_talks,
        delay = 3*TICRATE, -- This is the delay from finishing drawing the text until the textbox progresses automatically. Set to 1 for instant.
        next = 0 -- Setting a next ID of "0" closes the textbox.
    },
    
    [5] = { -- "..."
        name = "Sonic",
        portrait = {"sonic", SPR2_TBXA, B, 1},
        color = SKINCOLOR_BLUE,
        text = "...|del12y-you okay, bud?",
        sound = sfx_talks,
        next = 6
    },
    [6] = {
        name = "Sonic",
        portrait = {"sonic", SPR2_TBXA, C, 1},
        color = SKINCOLOR_BLUE,
        text = "|shk2I-|shk1|esc\x85Is something wrong|esc\x80?|rst",
        sound = sfx_talks,
        next = 7
    },
    [7] = {
        name = "Sonic",
        portrait = {"sonic", SPR2_TBXA, D, 1},
        color = SKINCOLOR_BLUE,
        text = "|pau02.|pau04.|pau06.Y'know what?\nD|pau08-Don't answer that. |shk1I'm sure you'll be fine!|rst |del13Heh-heh...",
        sound = sfx_talks,
        mini = { -- Mini-text, similar to Deltarune. Yes.
            {portrait = {"tails", B}, color = SKINCOLOR_ORANGE, text = "...uh?", pos = "down"} -- Portrait (has to use the TBXM sprite, no angles), color, text, position.
        },
        script = function(player) -- This runs once the textbox is displayed. Can be used to lock the player out of activating the box again.
            player.weird = true
            S_StartSound(nil, sfx_adderr, player)
        end,
        next = 0
    }
}

--[[ Note to self:
|delxy - Set delay between characters drawn, including spaces. Default is |del11 - 1 char per 1 tic. Decimal. Both MUST be nonzero, will be set to 1 if found as 0.
         x: how many characters to draw per tic
         y: how many tics to wait until the next char
|paunn - Pause for nn tics. This pauses AFTER drawing the next character. Decimal. MUST be nonzero, will be set to 1 if found as 0.
|shkn - Shake text. 1 - light, 2 - medium, 3 - intense
|wav - Wavy text
|rst - Reset
|esc - Parse escape sequence. Required (and recommended) for colors.
--]]

-- Now we summon the textbox.
addHook("PlayerThink", function(player)
    if not player.weird and not player.textBox.tree and (player.cmd.buttons & BT_CUSTOM1) then
        TB:DisplayBox(player, boxtree1) -- This function summons the textbox into the player.textBox field.
    end
end)

-- Let's do another one.
local boxtree2 = {
    [1] = {
        name = "C.Fighter",
        portrait = {"metalsonic", SPR2_STND, A, 8},
        color = SKINCOLOR_SILVER,
        text = "Textboxes are really cool!",
        sound = sfx_talk0,
        delay = TICRATE,
        next = 2
    },
    [2] = {
        name = "C.Fighter",
        portrait = {"metalsonic", SPR2_WAIT, B, 8},
        color = SKINCOLOR_SILVER,
        text = "Like, did you know that some textbox libraries feature some |esc\x83|wavreally wacky|esc\x80|rst effects?",
        sound = sfx_talk0,
        delay = 2*TICRATE,
        next = 3
    },
    [3] = {
        name = "C.Fighter",
        portrait = {"metalsonic", SPR2_WAIT, B, 8},
        color = SKINCOLOR_SILVER,
        text = "I mean, you can literally |shk3shake the text around|rst. Maybe lightly to sound a bit |shk1n-nervous|rst?",
        sound = sfx_talk0,
        delay = 2*TICRATE,
        next = 4
    },
    [4] = {
        name = "C.Fighter",
        portrait = {"metalsonic", SPR2_EDGE, A, 8},
        color = SKINCOLOR_SILVER,
        text = "Oh yeah, you can move during this box. Interesitng.",
        sound = sfx_talk0,
        delay = 2*TICRATE,
        next = 5
    },
    [5] = {
        name = "C.Fighter",
        portrait = {"metalsonic", SPR2_PAIN, A, 8},
        color = SKINCOLOR_SILVER,
        text = "Alright, alright. I won't distract you any longer.",
        sound = sfx_talk0,
        delay = 2*TICRATE,
        next = 0
    },
}
-- You read it right!
addHook("PlayerThink", function(player)
    if not player.weird and not player.textBox.tree and (player.cmd.buttons & BT_CUSTOM2) then
        TB:DisplayBox(player, boxtree2, true) -- You can DISABLE the control lock for the box!
    end -- Then you won't be able to interact with it, though - make sure the box has no choice questions.
end)